@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-__version__ = '0.2.5'
+__version__ = '0.2.6'
 
 from sys import version_info as _vi
 py3 = _vi [0] > 2
@@ -11,8 +11,8 @@ _xmlrpclib = xmlrpcutil.get_xmlrpclib ()
 
 
 from . import base, client, tickets, security, tools, naming, plugins, async
-from base import Service
-from interfaces import CryptoInterface, MetaInterface, Namespace
+from .base import Service
+from .interfaces import CryptoInterface, MetaInterface, Namespace
 
 
 import cherrypy
