@@ -19,7 +19,7 @@ def error_info ():
         message = unicode (e.args [0])
         code = utils.to (int, e.args [1], 1)
     else:
-        message = u'{}: {}'.format (type (e).__name__, e)
+        message = u'{}: {}'.format (type (e).__name__, str(e).decode('utf-8'))
         code = 1
     return (message, code)
 
@@ -41,7 +41,7 @@ class RpcAsyncProcess (object):
         
         self.thread = threading.Thread (target = self.run, args = args)
     
-    def callback (self, url, res):
+    def callback (self, url, *res):
         uri, method = url.rsplit (':', 1)
         svc = pgpxmlrpc.Service (
             uri = uri,
@@ -72,7 +72,7 @@ class RpcAsyncProcess (object):
         except Exception:
             try:
                 if self.cb_error:
-                    self.callback (self.cb_error, error_info ())
+                    self.callback (self.cb_error, *error_info ())
             except:
                 cherrypy.log.error ('Error while callback %s' % self.cb_error,
                     'RPCAsync', severity = logging.ERROR, traceback = True)
