@@ -7,6 +7,11 @@ from cherrypy import _cpconfig
 from . import security
 from . import interfaces
 
+try:
+    basestring
+except:
+    basestring = str
+
 
 def service ():
     '''
